//------------------------------------------------------------------------------
//
// FILENAME:   AI_Iron_City_on_the_Edge.cs
//
// Author:    Koyote

$missionName = " AI_Iron_City_on_the_Edge";

exec("multiplayerStdLib.cs");
exec("DMstdLib.cs");

//-----------------------------------------------------------------------------

Pilot Trainer
{
   id = 28;
   
   skill =1.0;
   accuracy = 1.0;
   aggressiveness = 1.0;
   activateDist = 2000.0;
   deactivateBuff = 3000.0;
   targetFreq = 4.0;
   trackFreq = 0.1;
   fireFreq = 0.1;
   LOSFreq = 0.4;
   name = "Trainer";
};

function initGlobalVars()
{
   $scoringFreeze = false;
   
   %playerCount = playerManager::getPlayerCount();
	// clear all points for the players
   for (%p = 0; %p < %playerCount; %p++)
	{
		%player = playerManager::getPlayerNum(%p);
      %player.numKills = 0;
   }

}

//-----------------------------------------------------------------------------

function setDefaultMissionOptions()
{
   $server::TeamPlay        = true;
   $server::AllowTeamPlay   = true;   
   $server::AllowDeathmatch = false;
   
   $server::AllowTeamYellow = true;
   $server::AllowTeamBlue   = true;
   $server::AllowTeamRed    = true;
   $server::AllowTeamPurple = false;

   $server::disableTeamYellow = false;
   $server::disableTeamBlue   = true;
   $server::disableTeamRed    = true;
   $server::disableTeamPurple = true;

}

//-----------------------------------------------------------------------------

function onMissionStart()
{
	marsSounds();

}

//-----------------------------------------------------------------------------

function onMissionLoad()
{
   cdAudioCycle("Purge", "Terror", "Watching"); 

}

//-----------------------------------------------------------------------------

function player::onAdd(%this)
{
   for ( %i=0; %i<3; %i++ )
      %this.AI[%i] = 0;

   %this.numKills = 0;

   say(%this, 0, "Welcome to Koyote's AI Tank Training!");
   say(%this, 0, "All Players must be on the Yellow Team! 3-5 Max recommended!");
   say(%this, 0, "One AI Tank will attack each player at a time!");
   say(%this, 0, "Use Teamwork to Help each other out!");
   say(%this, 0, "Check out the Iron Brigade at http://pluto.spaceports.com/~ibrigade/main.html");
}

//-----------------------------------------------------------------------------
// When humans drop in, assign an AI to attack them.
// Remove extra AI's if they had AI's but dropped in at a lower base.

function vehicle::onAdd(%vehicle)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicle);

   if( %player ) // which means it's a human
   {
      echo ("--------- players AI[0] ", %player.AI[0] );
      echo ("--------- players AI[1] ", %player.AI[1] );
      echo ("--------- players AI[2] ", %player.AI[2] );

      if ( %player.AI[0] ) 
         schedule( "order(" @ %player.AI[0] @ ",attack," @ %vehicle @ ");", 5 );
      else
         schedule( "dropNewVehicle(" @ %player @ ");", 5 );

      if ( getTeam(%vehicle) != *IDSTR_TEAM_YELLOW )
      {
         if ( %player.AI[1] ) 
            schedule( "order(" @ %player.AI[1] @ ",attack," @ %vehicle @ ");", 5 );
         else
            schedule( "dropNewVehicle(" @ %player @ ");", 5 );
      }
      else if ( %player.AI[1] )
      {
         deleteObject( %player.AI[1] );
         %player.AI[1] = 0;
      }

      if ( getTeam(%vehicle) == *IDSTR_TEAM_RED )
      {
         if ( %player.AI[2] ) 
            schedule( "order(" @ %player.AI[2] @ ",attack," @ %vehicle @ ");", 5 );
         else
            schedule( "dropNewVehicle(" @ %player @ ");", 5 );
      }
      else if ( %player.AI[2] )
      {
         deleteObject( %player.AI[2] );
         %player.AI[2] = 0;
      }
   }
}

//-----------------------------------------------------------------------------
// If player goes, get rid of his associated AI's too

function player::onRemove( %player )
{
   for ( %i=0; %i<3; %i++ )
   {
      if ( %player.AI[%i] )
         deleteObject( %player.AI[%i] );
   }
}

//-----------------------------------------------------------------------------

function vehicle::onDestroyed( %victimVeh, %destroyerVeh )
{
   if( getTeam( %destroyerVeh ) != getTeam( %victimVeh ) )
   {
      %player = playerManager::vehicleIdToPlayerNum( %destroyerVeh );
      %player.numKills++;      
      $HumanKills++;
   }

   //----------------------------------------------------------------
   // if it's an AI, drop a new one 
   if( getTeam( %victimVeh ) == *IDSTR_TEAM_PURPLE )
   {
      for ( %i=0; %i<4; %i++ )
      {
         %player = %victimVeh.owner;
         if ( %player.AI[%i] == %victimVeh )
         {
            %player.AI[%i] = 0;
            break;
         }
      }

// if you use resapawnVehicle instead of dropNewVehicle, you'll get the
// same AI opponent back after you kill him.
//      schedule( "respawnVehicle(" @ %victimVeh @ "," @ %destroyerVeh @ ");", 5 );

      schedule( "dropNewVehicle(" @ %player @ ");", 5 );

   }
   else
      $AIKills++;
}

//-----------------------------------------------------------------------------
// this creates a new random AI Herc

function getRandomAI()
{
   // check for valid ranges
   %i = RandomInt(1,50);
   if ( %i>=1 && %i<=8 )
      %i = RandomInt(6,7);
   if ( %i>=9 && %i<=17 )
      %i = RandomInt(15,16);
   if ( %i>=18 && %i<=24 )
      %i = RandomInt(25,26);
   if ( %i>=25 && %i<=37 )
      %i = RandomInt(31,32);
   if ( %i>=38 && %i<=50 )
      %i = 41;

   // get appropriate type Tank or Herc
   %type = Herc;
   if ( %i>5  && %i<= 8 )   %type = Tank;
   if ( %i>14 && %i<= 17 )  %type = Tank;
   if ( %i>24 && %i<= 26 )  %type = Tank;
   if ( %i>30 && %i<= 32 )  %type = Tank;
   if ( %i>40 && %i<= 41 )  %type = Tank;

   return NewObject( "AI" @ %i, %type, %i );
}

//-----------------------------------------------------------------------------
// this gives you a new random AI Herc

function dropNewVehicle( %player )
{
   %playerVeh = playerManager::playerNumToVehicleId(%player);                                                                                    
   %herc = getRandomAI();
   setTeam( %herc, *IDSTR_TEAM_PURPLE );
   setPilotId(%herc,28);
   %x = getPosition(%playerVeh,x)+RandomInt(-400,400);
   %y = getPosition(%playerVeh,y)+RandomInt(-400,400);
   %z = getPosition(%playerVeh,z)+150;
   setPosition( %herc, %x, %y, %z);
   schedule( "order(" @ %herc @ ",attack," @ %playerVeh @ ");", 5 );

   %herc.owner = %player;
   for ( %i=0; %i<4; %i++ )
   {
      if ( !%player.AI[%i] )
      {
         %player.AI[%i] = %herc;
         break;
      }
   }
}

//-----------------------------------------------------------------------------
// this respawns the AI Herc that just died

function respawnVehicle( %oldVeh, %destroyer )
{
   %player = playerManager::vehicleIdToPlayerNum( %destroyer );

   %x = getPosition(%destroyer,x)+200;
   %y = getPosition(%destroyer,y)+200;
   %z = getPosition(%destroyer,z)+150;

   %herc = hercVehicle(%oldVeh);
   setPosition(%herc, %x, %y, %z);
   schedule( "deleteObject(" @ %oldVeh @ ");", $respawnDealNoHq + 10 );
   addToSet( "MissionGroup", %herc );

   %herc.owner = %player;
   for ( %i=0; %i<4; %i++ )
   {
      if ( !%player.AI[%i] )
      {
         %player.AI[%i] = %herc;
         break;
      }
   }
}

//------------------------------------------------------------------------------
// Healing Pad Functionality
//------------------------------------------------------------------------------
function ZenHeal::trigger::onEnter(%this, %object)
{
   Zen::onEnter(%this, %object, *IDMULT_CHAT_HEALPAD, true, true);  
}
function ZenHeal::trigger::onContact(%this, %object)
{
   Zen::work(%this, %object, $healRate, 0, $padWaitTime, true); 
}

//------------------------------------------------------------------------------
// Ammo Pad Functionality
//------------------------------------------------------------------------------
function ZenAmmo::trigger::onEnter(%this, %object)
{
   Zen::onEnter(%this, %object, *IDMULT_CHAT_AMMOPAD, true, true);  
}

function ZenAmmo::trigger::onContact(%this, %object)
{
   Zen::work(%this, %object, 0, $ammoRate, $padWaitTime, true); 
}
// Water Tower splash functionality
function structure::onDestroyed(%this, %attackerId){
	// Which water tower was destroyed?
	if(%this == getObjectId("MissionGroup\\BlueBase\\WaterTower1")){
		setShapeVisibility(getObjectId("MissionGroup\\BlueBase\\Splash1"), true);
		playAnimSequence(getObjectId("MissionGroup\\BlueBase\\Splash1"), 0, true);
	}
	else if(%this == getObjectId("MissionGroup\\BlueBase\\WaterTower2")){
		setShapeVisibility(getObjectId("MissionGroup\\BlueBase\\Splash2"), true);
		playAnimSequence(getObjectId("MissionGroup\\BlueBase\\Splash2"), 0, true);
	}
	else if(%this == getObjectId("MissionGroup\\BlueBase\\WaterTower3")){
		setShapeVisibility(getObjectId("MissionGroup\\BlueBase\\Splash3"), true);
		playAnimSequence(getObjectId("MissionGroup\\BlueBase\\Splash3"), 0, true);
	}
}
